==> verifai_sdk-1.0.0.tar.gz: android/src/main/kotlin/com/verifai/verifai_sdk/VerifaiSdkPlugin.kt <==
package com.verifai.verifai_sdk

import android.app.Activity
import android.graphics.BitmapFactory
import android.util.Log
import androidx.annotation.NonNull
import com.verifai.core.Verifai
import com.verifai.core.exceptions.LicenceNotValidException
import com.verifai.core.listeners.VerifaiResultListener
import com.verifai.core.result.VerifaiResult
import com.verifai.liveness.VerifaiLiveness
import com.verifai.liveness.VerifaiLivenessCheckListener
import com.verifai.liveness.checks.*
import com.verifai.liveness.result.VerifaiLivenessCheckResults
import com.verifai.nfc.VerifaiNfc
import com.verifai.nfc.VerifaiNfcResultListener
import com.verifai.nfc.result.VerifaiNfcResult
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding

/** VerifaiSdkPlugin */
class VerifaiSdkPlugin : FlutterPlugin, ActivityAware, Messages.CoreApi, Messages.LivenessApi,
    Messages.NfcApi {
    private var activity: Activity? = null
    private lateinit var flutterCoreApi: Messages.CoreResultApi
    private lateinit var flutterLivenessApi: Messages.LivenessResultApi
    private lateinit var flutterNfcApi: Messages.NfcResultApi

    override fun onAttachedToActivity(activityPluginBinding: ActivityPluginBinding) {
        activity = activityPluginBinding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
        activity = null
    }

    override fun onReattachedToActivityForConfigChanges(activityPluginBinding: ActivityPluginBinding) {
        activity = activityPluginBinding.activity
    }

    override fun onDetachedFromActivity() {
        activity = null
    }

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        // Native api
        Messages.CoreApi.setup(flutterPluginBinding.binaryMessenger, this)
        Messages.LivenessApi.setup(flutterPluginBinding.binaryMessenger, this)
        Messages.NfcApi.setup(flutterPluginBinding.binaryMessenger, this)

        // Flutter api
        flutterCoreApi = Messages.CoreResultApi(flutterPluginBinding.binaryMessenger)
        flutterLivenessApi = Messages.LivenessResultApi(flutterPluginBinding.binaryMessenger)
        flutterNfcApi = Messages.NfcResultApi(flutterPluginBinding.binaryMessenger)
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        Messages.CoreApi.setup(binding.binaryMessenger, null)
        Messages.LivenessApi.setup(binding.binaryMessenger, null)
        Messages.NfcApi.setup(binding.binaryMessenger, null)
    }

    override fun setLicence(licence: String) {
        try {
            Verifai.setLicence(activity!!, licence)
        } catch (e: Exception) {
            e.message?.let { flutterCoreApi.onError(it) {} }
        }
    }

    override fun configure(configuration: Messages.Configuration) {
        try {
            Verifai.configure(configuration.convertFromMessageData())
        } catch (e: Exception) {
            e.message?.let { flutterCoreApi.onError(it) {} }
        }
    }

    override fun start() {
        if (activity == null) {
            Log.e(TAG, "Activity can't be null")
            return
        }

        Verifai.startScan(activity!!, object : VerifaiResultListener {
            override fun onSuccess(result: VerifaiResult) {
                flutterCoreApi.onSuccess(result.convertToMessageData()) {}
            }

            override fun onCanceled() {
                flutterCoreApi.onCancelled() {}
            }

            override fun onError(e: Throwable) {
                if (e is LicenceNotValidException) {
                    Log.e(TAG, "Authentication failed")
                }
                e.message?.let { flutterCoreApi.onError(it) {} }
            }
        })
    }

    override fun start(config: Messages.LivenessConfiguration) {
        if (activity == null) {
            Log.e(TAG, "Activity can't be null")
            return
        }

        try {
            val checks = ArrayList<VerifaiLivenessCheck>()
            config.checks?.let {
                for (check in it) {
                    when (check.type) {
                        Messages.LivenessCheckType.closeEyes -> {
                            var closeEyes = CloseEyes(activity!!)
                            check.args?.let { c ->
                                if (c.containsKey("numberOfSeconds")) {
                                    // Assign new CloseEyes instance because numberOfSeconds is immutable
                                    val numberOfSeconds = c["numberOfSeconds"]
                                    if (numberOfSeconds is Double) {
                                        closeEyes =
                                            CloseEyes(activity!!, numberOfSeconds)
                                    } else if (numberOfSeconds is Int) {
                                        closeEyes =
                                            CloseEyes(activity!!, numberOfSeconds.toDouble())
                                    } else {
                                        throw Exception("CloseEyes argument 'numberOfSeconds should be either an Int or a Double")
                                    }
                                }
                                if (c.containsKey("instruction")) {
                                    closeEyes.instruction = c["instruction"] as String
                                }
                            }
                            checks.add(closeEyes)
                        }
                        Messages.LivenessCheckType.speech -> {
                            var speech = Speech(activity!!)
                            check.args?.let { c ->
                                if (c.containsKey("speechRequirement")) {
                                    // Assign new Speech instance because speechRequirement is immutable
                                    speech = Speech(activity!!, c["speechRequirement"] as String)
                                }
                                if (c.containsKey("instruction")) {
                                    speech.instruction = c["instruction"] as String
                                }
                            }
                            checks.add(speech)
                        }
                        Messages.LivenessCheckType.tilt -> {
                            var tilt = Tilt(activity!!)
                            check.args?.let { c ->
                                if (c.containsKey("faceAngleRequirement")) {
                                    // Assign new Tilt instance because faceAngleRequirement is immutable
                                    tilt = Tilt(activity!!, c["faceAngleRequirement"] as Int)
                                }
                                if (c.containsKey("instruction")) {
                                    tilt.instruction = c["instruction"] as String
                                }
                            }
                            checks.add(tilt)
                        }
                        Messages.LivenessCheckType.faceMatching -> {
                            check.args?.let { c ->
                                val byteImage = c["documentImage"] as ByteArray
                                val image =
                                    BitmapFactory.decodeByteArray(byteImage, 0, byteImage.size)
                                val faceMatching = FaceMatching(activity!!, image)
                                if (c.containsKey("instruction")) {
                                    faceMatching.instruction = c["instruction"] as String
                                }
                                checks.add(faceMatching)
                            }
                        }
                        else -> {
                            throw Exception("No valid liveness check type")
                        }
                    }
                }
            }
            VerifaiLiveness.start(activity!!, checks, object : VerifaiLivenessCheckListener {
                override fun onResult(results: VerifaiLivenessCheckResults) {
                    flutterLivenessApi.onSuccess(results.convertToMessageData()) {}
                }

                override fun onError(e: Throwable) {
                    e.message?.let { flutterLivenessApi.onError(it) {} }
                }
            })
        } catch (e: Exception) {
            e.message?.let { flutterLivenessApi.onError(it) {} }
        }
    }

    override fun start(config: Messages.NfcConfiguration, coreResult: Messages.CoreResult) {
        if (activity == null) {
            Log.e(TAG, "Activity can't be null")
            return
        }

        val verifaiResult = VerifaiResult()
        verifaiResult.mrzData = coreResult.mrzData?.convertFromMessageData()
        verifaiResult.document = coreResult.document?.convertFromMessageData()
        VerifaiNfc.start(
            activity!!,
            verifaiResult,
            config.retrieveImage ?: true,
            object : VerifaiNfcResultListener {
                override fun onResult(result: VerifaiNfcResult) {
                    flutterNfcApi.onSuccess(result.convertToMessageData()) {}
                }

                override fun onCanceled() {
                    flutterNfcApi.onCancelled() {}
                }

                override fun onError(e: Throwable) {
                    e.message?.let { flutterNfcApi.onError(it) {} }
                }
            },
            config.showInstructionScreens ?: true
        )
    }

    companion object {
        const val TAG = "VFP"
    }
}

==> verifai_sdk-1.1.0.tar.gz: android/src/main/kotlin/com/verifai/verifai_sdk/VerifaiSdkPlugin.kt <==
package com.verifai.verifai_sdk

import android.app.Activity
import android.graphics.BitmapFactory
import android.util.Log
import androidx.annotation.NonNull
import com.verifai.core.Verifai
import com.verifai.core.exceptions.LicenceNotValidException
import com.verifai.core.listeners.VerifaiResultListener
import com.verifai.core.result.VerifaiResult
import com.verifai.liveness.VerifaiLiveness
import com.verifai.liveness.VerifaiLivenessCheckListener
import com.verifai.liveness.checks.*
import com.verifai.liveness.result.VerifaiLivenessCheckResults
import com.verifai.nfc.VerifaiNfc
import com.verifai.nfc.VerifaiNfcResultListener
import com.verifai.nfc.result.VerifaiNfcResult
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding

/** VerifaiSdkPlugin */
class VerifaiSdkPlugin : FlutterPlugin, ActivityAware, Messages.CoreApi, Messages.LivenessApi,
    Messages.NfcApi {
    private var activity: Activity? = null
    private lateinit var flutterCoreApi: Messages.CoreResultApi
    private lateinit var flutterLivenessApi: Messages.LivenessResultApi
    private lateinit var flutterNfcApi: Messages.NfcResultApi

    override fun onAttachedToActivity(activityPluginBinding: ActivityPluginBinding) {
        activity = activityPluginBinding.activity
    }

    override fun onDetachedFromActivityForConfigChanges() {
        activity = null
    }

    override fun onReattachedToActivityForConfigChanges(activityPluginBinding: ActivityPluginBinding) {
        activity = activityPluginBinding.activity
    }

    override fun onDetachedFromActivity() {
        activity = null
    }

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        // Native api
        Messages.CoreApi.setup(flutterPluginBinding.binaryMessenger, this)
        Messages.LivenessApi.setup(flutterPluginBinding.binaryMessenger, this)
        Messages.NfcApi.setup(flutterPluginBinding.binaryMessenger, this)

        // Flutter api
        flutterCoreApi = Messages.CoreResultApi(flutterPluginBinding.binaryMessenger)
        flutterLivenessApi = Messages.LivenessResultApi(flutterPluginBinding.binaryMessenger)
        flutterNfcApi = Messages.NfcResultApi(flutterPluginBinding.binaryMessenger)
    }

    override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
        Messages.CoreApi.setup(binding.binaryMessenger, null)
        Messages.LivenessApi.setup(binding.binaryMessenger, null)
        Messages.NfcApi.setup(binding.binaryMessenger, null)
    }

    override fun setLicence(licence: String) {
        try {
            Verifai.setLicence(activity!!, licence)
        } catch (e: Exception) {
            e.message?.let { flutterCoreApi.onError(it) {} }
        }
    }

    override fun configure(configuration: Messages.Configuration) {
        try {
            Verifai.configure(configuration.convertFromMessageData())
        } catch (e: Exception) {
            e.message?.let { flutterCoreApi.onError(it) {} }
        }
    }

    override fun start() {
        if (activity == null) {
            Log.e(TAG, "Activity can't be null")
            return
        }

        Verifai.startScan(activity!!, object : VerifaiResultListener {
            override fun onSuccess(result: VerifaiResult) {
                flutterCoreApi.onSuccess(result.convertToMessageData()) {}
            }

            override fun onCanceled() {
                flutterCoreApi.onCancelled() {}
            }

            override fun onError(e: Throwable) {
                if (e is LicenceNotValidException) {
                    Log.e(TAG, "Authentication failed")
                }
                e.message?.let { flutterCoreApi.onError(it) {} }
            }
        })
    }

    override fun start(config: Messages.LivenessConfiguration) {
        if (activity == null) {
            Log.e(TAG, "Activity can't be null")
            return
        }

        try {
            val checks = ArrayList<VerifaiLivenessCheck>()
            config.checks?.let {
                for (check in it) {
                    when (check.type) {
                        Messages.LivenessCheckType.CLOSE_EYES -> {
                            var closeEyes = CloseEyes(activity!!)
                            check.args?.let { c ->
                                if (c.containsKey("numberOfSeconds")) {
                                    // Assign new CloseEyes instance because numberOfSeconds is immutable
                                    val numberOfSeconds = c["numberOfSeconds"]
                                    if (numberOfSeconds is Double) {
                                        closeEyes =
                                            CloseEyes(activity!!, numberOfSeconds)
                                    } else if (numberOfSeconds is Int) {
                                        closeEyes =
                                            CloseEyes(activity!!, numberOfSeconds.toDouble())
                                    } else {
                                        throw Exception("CloseEyes argument 'numberOfSeconds should be either an Int or a Double")
                                    }
                                }
                                if (c.containsKey("instruction")) {
                                    closeEyes.instruction = c["instruction"] as String
                                }
                            }
                            checks.add(closeEyes)
                        }
                        Messages.LivenessCheckType.SPEECH -> {
                            var speech = Speech(activity!!)
                            check.args?.let { c ->
                                if (c.containsKey("speechRequirement")) {
                                    // Assign new Speech instance because speechRequirement is immutable
                                    speech = Speech(activity!!, c["speechRequirement"] as String)
                                }
                                if (c.containsKey("instruction")) {
                                    speech.instruction = c["instruction"] as String
                                }
                            }
                            checks.add(speech)
                        }
                        Messages.LivenessCheckType.TILT -> {
                            var tilt = Tilt(activity!!)
                            check.args?.let { c ->
                                if (c.containsKey("faceAngleRequirement")) {
                                    // Assign new Tilt instance because faceAngleRequirement is immutable
                                    tilt = Tilt(activity!!, c["faceAngleRequirement"] as Int)
                                }
                                if (c.containsKey("instruction")) {
                                    tilt.instruction = c["instruction"] as String
                                }
                            }
                            checks.add(tilt)
                        }
                        Messages.LivenessCheckType.FACE_MATCHING -> {
                            check.args?.let { c ->
                                val byteImage = c["documentImage"] as ByteArray
                                val image =
                                    BitmapFactory.decodeByteArray(byteImage, 0, byteImage.size)
                                val faceMatching = FaceMatching(activity!!, image)
                                if (c.containsKey("instruction")) {
                                    faceMatching.instruction = c["instruction"] as String
                                }
                                checks.add(faceMatching)
                            }
                        }
                        else -> {
                            throw Exception("No valid liveness check type")
                        }
                    }
                }
            }
            VerifaiLiveness.start(activity!!, checks, object : VerifaiLivenessCheckListener {
                override fun onResult(results: VerifaiLivenessCheckResults) {
                    flutterLivenessApi.onSuccess(results.convertToMessageData()) {}
                }

                override fun onError(e: Throwable) {
                    e.message?.let { flutterLivenessApi.onError(it) {} }
                }
            })
        } catch (e: Exception) {
            e.message?.let { flutterLivenessApi.onError(it) {} }
        }
    }

    override fun start(config: Messages.NfcConfiguration, coreResult: Messages.CoreResult) {
        if (activity == null) {
            Log.e(TAG, "Activity can't be null")
            return
        }

        val verifaiResult = VerifaiResult()
        verifaiResult.mrzData = coreResult.mrzData?.convertFromMessageData()
        verifaiResult.document = coreResult.document?.convertFromMessageData()
        VerifaiNfc.start(
            activity!!,
            verifaiResult,
            config.retrieveImage ?: true,
            object : VerifaiNfcResultListener {
                override fun onResult(result: VerifaiNfcResult) {
                    flutterNfcApi.onSuccess(result.convertToMessageData()) {}
                }

                override fun onCanceled() {
                    flutterNfcApi.onCancelled() {}
                }

                override fun onError(e: Throwable) {
                    e.message?.let { flutterNfcApi.onError(it) {} }
                }
            },
            config.showInstructionScreens ?: true
        )
    }

    companion object {
        const val TAG = "VFP"
    }
}
